==> apache-openmeetings-7.2.0-src.tar.gz: openmeetings-db/src/main/java/org/apache/openmeetings/db/dto/file/FileExplorerObject.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License") +  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.openmeetings.db.dto.file;

import java.io.Serializable;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.openmeetings.db.entity.file.FileItem;

/**
 * @author sebastianwagner
 *
 */
@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
public class FileExplorerObject implements Serializable {
	private static final long serialVersionUID = 1L;

	private List<FileItemDTO> userHome;
	private List<FileItemDTO> roomHome;
	private Long userHomeSize;
	private Long roomHomeSize;

	public List<FileItemDTO> getUserHome() {
		return userHome;
	}

	public void setUser(List<FileItem> list, long size) {
		this.userHome = FileItemDTO.list(list);
		this.userHomeSize = size;
	}

	public List<FileItemDTO> getRoomHome() {
		return roomHome;
	}

	public void setRoom(List<FileItem> list, long size) {
		this.roomHome = FileItemDTO.list(list);
		this.roomHomeSize = size;
	}

	public Long getUserHomeSize() {
		return userHomeSize;
	}

	public void setUserHomeSize(Long userHomeSize) {
		this.userHomeSize = userHomeSize;
	}

	public Long getRoomHomeSize() {
		return roomHomeSize;
	}

	public void setRoomHomeSize(Long roomHomeSize) {
		this.roomHomeSize = roomHomeSize;
	}
}

==> apache-openmeetings-8.0.0-src.tar.gz: openmeetings-db/src/main/java/org/apache/openmeetings/db/dto/file/FileExplorerObject.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License") +  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.openmeetings.db.dto.file;

import java.io.Serializable;
import java.util.List;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlRootElement;

import org.apache.openmeetings.db.entity.file.FileItem;

/**
 * @author sebastianwagner
 *
 */
@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
public class FileExplorerObject implements Serializable {
	private static final long serialVersionUID = 1L;

	private List<FileItemDTO> userHome;
	private List<FileItemDTO> roomHome;
	private Long userHomeSize;
	private Long roomHomeSize;

	public List<FileItemDTO> getUserHome() {
		return userHome;
	}

	public void setUser(List<FileItem> list, long size) {
		this.userHome = FileItemDTO.list(list);
		this.userHomeSize = size;
	}

	public List<FileItemDTO> getRoomHome() {
		return roomHome;
	}

	public void setRoom(List<FileItem> list, long size) {
		this.roomHome = FileItemDTO.list(list);
		this.roomHomeSize = size;
	}

	public Long getUserHomeSize() {
		return userHomeSize;
	}

	public void setUserHomeSize(Long userHomeSize) {
		this.userHomeSize = userHomeSize;
	}

	public Long getRoomHomeSize() {
		return roomHomeSize;
	}

	public void setRoomHomeSize(Long roomHomeSize) {
		this.roomHomeSize = roomHomeSize;
	}
}
